# -*- coding: utf-8 -*-

from . import (
    steammessages_chat,
    steammessages_econ,
    steammessages_friendmessages,
    steammessages_gameservers,
    steammessages_player,
    steammessages_twofactor,
    steammessages_useraccount,
)

__all__ = ("UMS",)


UMS = {
    "GameServers.GetServerList#1_Request": steammessages_gameservers.CGameServers_GetServerList_Request,
    "GameServers.GetServerList#1_Response": steammessages_gameservers.CGameServers_GetServerList_Response,
    "GameServers.GetServerSteamIDsByIP#1_Request": steammessages_gameservers.CGameServers_GetServerSteamIDsByIP_Request,
    "GameServers.GetServerSteamIDsByIP#1_Response": steammessages_gameservers.CGameServers_IPsWithSteamIDs_Response,
    "GameServers.GetServerIPsBySteamID#1_Request": steammessages_gameservers.CGameServers_GetServerIPsBySteamID_Request,
    "GameServers.GetServerIPsBySteamID#1_Response": steammessages_gameservers.CGameServers_IPsWithSteamIDs_Response,
    "TwoFactor.AddAuthenticator#1_Request": steammessages_twofactor.CTwoFactor_AddAuthenticator_Request,
    "TwoFactor.AddAuthenticator#1_Response": steammessages_twofactor.CTwoFactor_AddAuthenticator_Response,
    "TwoFactor.FinalizeAddAuthenticator#1_Request": steammessages_twofactor.CTwoFactor_FinalizeAddAuthenticator_Request,
    "TwoFactor.FinalizeAddAuthenticator#1_Response": steammessages_twofactor.CTwoFactor_FinalizeAddAuthenticator_Response,
    "TwoFactor.SendEmail#1_Request": steammessages_twofactor.CTwoFactor_SendEmail_Request,
    "TwoFactor.SendEmail#1_Response": steammessages_twofactor.CTwoFactor_SendEmail_Response,
    "TwoFactor.RemoveAuthenticator#1_Request": steammessages_twofactor.CTwoFactor_RemoveAuthenticator_Request,
    "TwoFactor.RemoveAuthenticator#1_Response": steammessages_twofactor.CTwoFactor_RemoveAuthenticator_Response,
    "Player.GetGameBadgeLevels#1_Request": steammessages_player.CPlayer_GetGameBadgeLevels_Request,
    "Player.GetGameBadgeLevels#1_Response": steammessages_player.CPlayer_GetGameBadgeLevels_Response,
    "Player.GetNicknameList#1_Request": steammessages_player.CPlayer_GetNicknameList_Request,
    "Player.GetNicknameList#1_Response": steammessages_player.CPlayer_GetNicknameList_Response,
    "Player.GetEmoticonList#1_Request": steammessages_player.CPlayer_GetEmoticonList_Request,
    "Player.GetEmoticonList#1_Response": steammessages_player.CPlayer_GetEmoticonList_Response,
    "Player.GetPrivacySettings#1_Request": steammessages_player.CPlayer_GetPrivacySettings_Request,
    "Player.GetPrivacySettings#1_Response": steammessages_player.CPlayer_GetPrivacySettings_Response,
    "Player.GetOwnedGames#1_Request": steammessages_player.CPlayer_GetLastPlayedTimes_Request,
    "Player.GetOwnedGames#1_Response": steammessages_player.CPlayer_GetLastPlayedTimes_Response,
    "Econ.GetAssetClassInfo#1_Request": steammessages_econ.CEcon_GetAssetClassInfo_Request,
    "Econ.GetAssetClassInfo#1_Response": steammessages_econ.CEcon_GetAssetClassInfo_Response,
    "Econ.GetTradeOfferAccessToken#1_Request": steammessages_econ.CEcon_GetTradeOfferAccessToken_Request,
    "Econ.GetTradeOfferAccessToken#1_Response": steammessages_econ.CEcon_GetTradeOfferAccessToken_Response,
    "ChatRoom.CreateChatRoomGroup#1_Request": steammessages_chat.CChatRoom_CreateChatRoomGroup_Request,
    "ChatRoom.CreateChatRoomGroup#1_Response": steammessages_chat.CChatRoom_CreateChatRoomGroup_Response,
    "ChatRoom.SaveChatRoomGroup#1_Request": steammessages_chat.CChatRoom_SaveChatRoomGroup_Request,
    "ChatRoom.SaveChatRoomGroup#1_Response": steammessages_chat.CChatRoom_SaveChatRoomGroup_Response,
    "ChatRoom.RenameChatRoomGroup#1_Request": steammessages_chat.CChatRoom_RenameChatRoomGroup_Request,
    "ChatRoom.RenameChatRoomGroup#1_Response": steammessages_chat.CChatRoom_RenameChatRoomGroup_Response,
    "ChatRoom.SetChatRoomGroupTagline#1_Request": steammessages_chat.CChatRoom_SetChatRoomGroupTagline_Request,
    "ChatRoom.SetChatRoomGroupTagline#1_Response": steammessages_chat.CChatRoom_SetChatRoomGroupTagline_Response,
    "ChatRoom.SetChatRoomGroupAvatar#1_Request": steammessages_chat.CChatRoom_SetChatRoomGroupAvatar_Request,
    "ChatRoom.SetChatRoomGroupAvatar#1_Response": steammessages_chat.CChatRoom_SetChatRoomGroupAvatar_Response,
    "ChatRoom.MuteUserInGroup#1_Request": steammessages_chat.CChatRoom_MuteUser_Request,
    "ChatRoom.MuteUserInGroup#1_Response": steammessages_chat.CChatRoom_MuteUser_Response,
    "ChatRoom.KickUserFromGroup#1_Request": steammessages_chat.CChatRoom_KickUser_Request,
    "ChatRoom.KickUserFromGroup#1_Response": steammessages_chat.CChatRoom_KickUser_Response,
    "ChatRoom.SetUserBanState#1_Request": steammessages_chat.CChatRoom_SetUserBanState_Request,
    "ChatRoom.SetUserBanState#1_Response": steammessages_chat.CChatRoom_SetUserBanState_Response,
    "ChatRoom.RevokeInviteToGroup#1_Request": steammessages_chat.CChatRoom_RevokeInvite_Request,
    "ChatRoom.RevokeInviteToGroup#1_Response": steammessages_chat.CChatRoom_RevokeInvite_Response,
    "ChatRoom.CreateRole#1_Request": steammessages_chat.CChatRoom_CreateRole_Request,
    "ChatRoom.CreateRole#1_Response": steammessages_chat.CChatRoom_CreateRole_Response,
    "ChatRoom.GetRoles#1_Request": steammessages_chat.CChatRoom_GetRoles_Request,
    "ChatRoom.GetRoles#1_Response": steammessages_chat.CChatRoom_GetRoles_Response,
    "ChatRoom.RenameRole#1_Request": steammessages_chat.CChatRoom_RenameRole_Request,
    "ChatRoom.RenameRole#1_Response": steammessages_chat.CChatRoom_RenameRole_Response,
    "ChatRoom.ReorderRole#1_Request": steammessages_chat.CChatRoom_ReorderRole_Request,
    "ChatRoom.ReorderRole#1_Response": steammessages_chat.CChatRoom_ReorderRole_Response,
    "ChatRoom.DeleteRole#1_Request": steammessages_chat.CChatRoom_DeleteRole_Request,
    "ChatRoom.DeleteRole#1_Response": steammessages_chat.CChatRoom_DeleteRole_Response,
    "ChatRoom.GetRoleActions#1_Request": steammessages_chat.CChatRoom_GetRoleActions_Request,
    "ChatRoom.GetRoleActions#1_Response": steammessages_chat.CChatRoom_GetRoleActions_Response,
    "ChatRoom.ReplaceRoleActions#1_Request": steammessages_chat.CChatRoom_ReplaceRoleActions_Request,
    "ChatRoom.ReplaceRoleActions#1_Response": steammessages_chat.CChatRoom_ReplaceRoleActions_Response,
    "ChatRoom.AddRoleToUser#1_Request": steammessages_chat.CChatRoom_AddRoleToUser_Request,
    "ChatRoom.AddRoleToUser#1_Response": steammessages_chat.CChatRoom_AddRoleToUser_Response,
    "ChatRoom.GetRolesForUser#1_Request": steammessages_chat.CChatRoom_GetRolesForUser_Request,
    "ChatRoom.GetRolesForUser#1_Response": steammessages_chat.CChatRoom_GetRolesForUser_Response,
    "ChatRoom.DeleteRoleFromUser#1_Request": steammessages_chat.CChatRoom_DeleteRoleFromUser_Request,
    "ChatRoom.DeleteRoleFromUser#1_Response": steammessages_chat.CChatRoom_DeleteRoleFromUser_Response,
    "ChatRoom.JoinChatRoomGroup#1_Request": steammessages_chat.CChatRoom_JoinChatRoomGroup_Request,
    "ChatRoom.JoinChatRoomGroup#1_Response": steammessages_chat.CChatRoom_JoinChatRoomGroup_Response,
    "ChatRoom.InviteFriendToChatRoomGroup#1_Request": steammessages_chat.CChatRoom_InviteFriendToChatRoomGroup_Request,
    "ChatRoom.InviteFriendToChatRoomGroup#1_Response": steammessages_chat.CChatRoom_InviteFriendToChatRoomGroup_Response,
    "ChatRoom.LeaveChatRoomGroup#1_Request": steammessages_chat.CChatRoom_LeaveChatRoomGroup_Request,
    "ChatRoom.LeaveChatRoomGroup#1_Response": steammessages_chat.CChatRoom_LeaveChatRoomGroup_Response,
    "ChatRoom.CreateChatRoom#1_Request": steammessages_chat.CChatRoom_CreateChatRoom_Request,
    "ChatRoom.CreateChatRoom#1_Response": steammessages_chat.CChatRoom_CreateChatRoom_Response,
    "ChatRoom.DeleteChatRoom#1_Request": steammessages_chat.CChatRoom_DeleteChatRoom_Request,
    "ChatRoom.DeleteChatRoom#1_Response": steammessages_chat.CChatRoom_DeleteChatRoom_Response,
    "ChatRoom.RenameChatRoom#1_Request": steammessages_chat.CChatRoom_RenameChatRoom_Request,
    "ChatRoom.RenameChatRoom#1_Response": steammessages_chat.CChatRoom_RenameChatRoom_Response,
    "ChatRoom.SendChatMessage#1_Request": steammessages_chat.CChatRoom_SendChatMessage_Request,
    "ChatRoom.SendChatMessage#1_Response": steammessages_chat.CChatRoom_SendChatMessage_Response,
    "ChatRoom.JoinVoiceChat#1_Request": steammessages_chat.CChatRoom_JoinVoiceChat_Request,
    "ChatRoom.JoinVoiceChat#1_Response": steammessages_chat.CChatRoom_JoinVoiceChat_Response,
    "ChatRoom.LeaveVoiceChat#1_Request": steammessages_chat.CChatRoom_LeaveVoiceChat_Request,
    "ChatRoom.LeaveVoiceChat#1_Response": steammessages_chat.CChatRoom_LeaveVoiceChat_Response,
    "ChatRoom.GetMessageHistory#1_Request": steammessages_chat.CChatRoom_GetMessageHistory_Request,
    "ChatRoom.GetMessageHistory#1_Response": steammessages_chat.CChatRoom_GetMessageHistory_Response,
    "ChatRoom.GetMyChatRoomGroups#1_Request": steammessages_chat.CChatRoom_GetMyChatRoomGroups_Request,
    "ChatRoom.GetMyChatRoomGroups#1_Response": steammessages_chat.CChatRoom_GetMyChatRoomGroups_Response,
    "ChatRoom.GetChatRoomGroupState#1_Request": steammessages_chat.CChatRoom_GetChatRoomGroupState_Request,
    "ChatRoom.GetChatRoomGroupState#1_Response": steammessages_chat.CChatRoom_GetChatRoomGroupState_Response,
    "ChatRoom.GetChatRoomGroupSummary#1_Request": steammessages_chat.CChatRoom_GetChatRoomGroupSummary_Request,
    "ChatRoom.GetChatRoomGroupSummary#1_Response": steammessages_chat.CChatRoom_GetChatRoomGroupSummary_Response,
    "ChatRoom.AckChatMessage#1": steammessages_chat.CChatRoom_AckChatMessage_Notification,
    "ChatRoom.CreateInviteLink#1_Request": steammessages_chat.CChatRoom_CreateInviteLink_Request,
    "ChatRoom.CreateInviteLink#1_Response": steammessages_chat.CChatRoom_CreateInviteLink_Response,
    "ChatRoom.GetInviteLinkInfo#1_Request": steammessages_chat.CChatRoom_GetInviteLinkInfo_Request,
    "ChatRoom.GetInviteLinkInfo#1_Response": steammessages_chat.CChatRoom_GetInviteLinkInfo_Response,
    "ChatRoom.GetInviteInfo#1_Request": steammessages_chat.CChatRoom_GetInviteInfo_Request,
    "ChatRoom.GetInviteInfo#1_Response": steammessages_chat.CChatRoom_GetInviteInfo_Response,
    "ChatRoom.GetInviteLinksForGroup#1_Request": steammessages_chat.CChatRoom_GetInviteLinksForGroup_Request,
    "ChatRoom.GetInviteLinksForGroup#1_Response": steammessages_chat.CChatRoom_GetInviteLinksForGroup_Response,
    "ChatRoom.GetBanList#1_Request": steammessages_chat.CChatRoom_GetBanList_Request,
    "ChatRoom.GetBanList#1_Response": steammessages_chat.CChatRoom_GetBanList_Response,
    "ChatRoom.GetInviteList#1_Request": steammessages_chat.CChatRoom_GetInviteList_Request,
    "ChatRoom.GetInviteList#1_Response": steammessages_chat.CChatRoom_GetInviteList_Response,
    "ChatRoom.DeleteInviteLink#1_Request": steammessages_chat.CChatRoom_DeleteInviteLink_Request,
    "ChatRoom.DeleteInviteLink#1_Response": steammessages_chat.CChatRoom_DeleteInviteLink_Response,
    "ChatRoom.SetSessionActiveChatRoomGroups#1_Request": steammessages_chat.CChatRoom_SetSessionActiveChatRoomGroups_Request,
    "ChatRoom.SetSessionActiveChatRoomGroups#1_Response": steammessages_chat.CChatRoom_SetSessionActiveChatRoomGroups_Response,
    "ChatRoom.SetUserChatGroupPreferences#1_Request": steammessages_chat.CChatRoom_SetUserChatGroupPreferences_Request,
    "ChatRoom.SetUserChatGroupPreferences#1_Response": steammessages_chat.CChatRoom_SetUserChatGroupPreferences_Response,
    "ChatRoom.DeleteChatMessages#1_Request": steammessages_chat.CChatRoom_DeleteChatMessages_Request,
    "ChatRoom.DeleteChatMessages#1_Response": steammessages_chat.CChatRoom_DeleteChatMessages_Response,
    "ChatRoomClient.NotifyIncomingChatMessage#1": steammessages_chat.CChatRoom_IncomingChatMessage_Notification,
    "ChatRoomClient.NotifyChatMessageModified#1": steammessages_chat.CChatRoom_ChatMessageModified_Notification,
    "ChatRoomClient.NotifyMemberStateChange#1": steammessages_chat.CChatRoom_MemberStateChange_Notification,
    "ChatRoomClient.NotifyChatRoomHeaderStateChange#1": steammessages_chat.CChatRoom_ChatRoomHeaderState_Notification,
    "ChatRoomClient.NotifyChatRoomGroupRoomsChange#1": steammessages_chat.CChatRoom_ChatRoomGroupRoomsChange_Notification,
    "ChatRoomClient.NotifyShouldRejoinChatRoomVoiceChat#1": steammessages_chat.CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification,
    "ChatRoomClient.NotifyChatGroupUserStateChanged#1": steammessages_chat.ChatRoomClient_NotifyChatGroupUserStateChanged_Notification,
    "ChatRoomClient.NotifyAckChatMessageEcho#1": steammessages_chat.CChatRoom_AckChatMessage_Notification,
    "ClanChatRooms.GetClanChatRoomInfo#1_Request": steammessages_chat.CClanChatRooms_GetClanChatRoomInfo_Request,
    "ClanChatRooms.GetClanChatRoomInfo#1_Response": steammessages_chat.CClanChatRooms_GetClanChatRoomInfo_Response,
    "FriendMessages.GetActiveMessageSessions#1_Request": steammessages_friendmessages.CFriendsMessages_GetActiveMessageSessions_Request,
    "FriendMessages.GetActiveMessageSessions#1_Response": steammessages_friendmessages.CFriendsMessages_GetActiveMessageSessions_Response,
    "FriendMessages.SendMessage#1_Request": steammessages_friendmessages.CFriendMessages_SendMessage_Request,
    "FriendMessages.SendMessage#1_Response": steammessages_friendmessages.CFriendMessages_SendMessage_Response,
    "FriendMessages.AckMessage#1": steammessages_friendmessages.CFriendMessages_AckMessage_Notification,
    "FriendMessagesClient.IncomingMessage#1": steammessages_friendmessages.CFriendMessages_IncomingMessage_Notification,
    "FriendMessagesClient.NotifyAckMessageEcho#1": steammessages_friendmessages.CFriendMessages_AckMessage_Notification,
    "UserAccount.CreateFriendInviteToken#1_Request": steammessages_useraccount.CUserAccount_CreateFriendInviteToken_Request,
    "UserAccount.CreateFriendInviteToken#1_Response": steammessages_useraccount.CUserAccount_CreateFriendInviteToken_Response,
    "UserAccount.GetFriendInviteTokens#1_Request": steammessages_useraccount.CUserAccount_GetFriendInviteTokens_Request,
    "UserAccount.GetFriendInviteTokens#1_Response": steammessages_useraccount.CUserAccount_GetFriendInviteTokens_Response,
    "UserAccount.ViewFriendInviteToken#1_Request": steammessages_useraccount.CUserAccount_ViewFriendInviteToken_Request,
    "UserAccount.ViewFriendInviteToken#1_Response": steammessages_useraccount.CUserAccount_ViewFriendInviteToken_Response,
    "UserAccount.RedeemFriendInviteToken#1_Request": steammessages_useraccount.CUserAccount_RedeemFriendInviteToken_Request,
    "UserAccount.RedeemFriendInviteToken#1_Response": steammessages_useraccount.CUserAccount_RedeemFriendInviteToken_Response,
    "UserAccount.RevokeFriendInviteToken#1_Request": steammessages_useraccount.CUserAccount_RevokeFriendInviteToken_Request,
    "UserAccount.RevokeFriendInviteToken#1_Response": steammessages_useraccount.CUserAccount_RevokeFriendInviteToken_Response,
}
